@@ -1,3 +1,7 @@
+"""
+`measure.py` houses the main `PyMeasure` and `PyMeasures` class.
+Once connected to your model, interacting with measure(s) will be done through these classes.
+"""
 import logging
 import pandas as pd
 from object import PyObject, PyObjects
@@ -23,11 +27,28 @@ class PyMeasure(PyObject):
         self._display.add_row("FormatString", self._object.FormatString)
 
     def get_dependencies(self) -> pd.DataFrame:
-        """Returns the dependant columns of a measure"""
+        """Returns the dependant objects of a measure.
+        Args:
+            self: The Measure Object
+
+        Returns:
+            pd.DataFrame: The Return Value is a Pandas dataframe
+                            which displays all the dependancies
+                            of the object.
+
+        """
         dmv_query = f"select * from $SYSTEM.DISCOVER_CALC_DEPENDENCY where [OBJECT] = '{self.Name}' and [TABLE] = '{self.Table.Name}'"
-        return self.Table.Model.Query(dmv_query)
+        return self.Table.Model.query(dmv_query)
 
 
 class PyMeasures(PyObjects):
+    """
+    Groups together multiple measures. See `PyObjects` class for what more it can do.
+    You can interact with `PyMeasures` straight from model. For ex: `model.Measures`.
+    Or through individual tables `model.Tables[TABLE_NAME].Measures`.
+    You can even filter down with `.Find()`. For example find all measures with `ratio` in name.
+    `model.Measures.Find('ratio')`.
+    """
+
     def __init__(self, objects) -> None:
         super().__init__(objects)
