@@ -5,7 +5,7 @@ import pytest
 import pytabular as p
 import os
 from pytabular import logic_utils
-from test.conftest import testing_storage
+from test.conftest import TestStorage
 
 
 @pytest.mark.parametrize("model", testing_parameters)
@@ -14,13 +14,13 @@ def test_basic_document_funcionality(model):
         docs = p.ModelDocumenter(model=model)
         docs.generate_documentation_pages()
         docs.save_documentation()
-        testing_storage.documentation_class = docs
+        TestStorage.documentation_class = docs
     except Exception:
         pytest.fail("Unsuccessful documentation generation..")
 
 
 def test_basic_documentation_removed():
-    docs_class = testing_storage.documentation_class
+    docs_class = TestStorage.documentation_class
     remove = f"{docs_class.save_location}/{docs_class.friendly_name}"
     logic_utils.remove_folder_and_contents(remove)
     assert os.path.exists(remove) is False
