@@ -9,21 +9,21 @@ from numpy import int64
 @pytest.mark.parametrize("model", testing_parameters)
 def test_values(model):
     """Tests for `Values()` of PyColumn class."""
-    vals = model.Tables[testingtablename].Columns[1].Values()
+    vals = model.Tables[testingtablename].Columns[1].values()
     assert isinstance(vals, pd.DataFrame) or isinstance(vals, int)
 
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_distinct_count_no_blank(model):
     """Tests No_Blank=True for `Distinct_Count()` of PyColumn class."""
-    vals = model.Tables[testingtablename].Columns[1].Distinct_Count(No_Blank=True)
+    vals = model.Tables[testingtablename].Columns[1].distinct_count(no_blank=True)
     assert isinstance(vals, int64)
 
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_distinct_count_blank(model):
     """Tests No_Blank=False for `Distinct_Count()` of PyColumn class."""
-    vals = model.Tables[testingtablename].Columns[1].Distinct_Count(No_Blank=False)
+    vals = model.Tables[testingtablename].Columns[1].distinct_count(no_blank=False)
     assert isinstance(vals, int64)
 
 
@@ -37,7 +37,7 @@ def test_get_sample_values(model):
 @pytest.mark.parametrize("model", testing_parameters)
 def test_query_every_column(model):
     """Tests `Query_All()` of PyColumns class."""
-    assert isinstance(model.Tables[testingtablename].Columns.Query_All(), pd.DataFrame)
+    assert isinstance(model.Tables[testingtablename].Columns.query_all(), pd.DataFrame)
 
 
 @pytest.mark.parametrize("model", testing_parameters)
